@@ -2,13 +2,26 @@ package Module::Provision::TraitFor::UpdatingContent;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants;
+use Class::Usul::Constants qw( EXCEPTION_CLASS OK );
 use Class::Usul::Functions qw( throw );
 use Unexpected::Functions  qw( Unspecified );
 use Moo::Role;
 
 requires qw( appldir loc manifest_paths next_argv output );
 
+# Private methods
+my $_get_ignore_rev_regex = sub {
+   my $self = shift;
+
+   my $ignore_rev = $self->appldir->catfile( '.gitignore-rev' )->chomp;
+
+   return $ignore_rev->exists ? join '|', $ignore_rev->getlines : undef;
+};
+
+my $_get_update_args = sub {
+   return ($_[ 0 ]->next_argv, $_[ 0 ]->next_argv);
+};
+
 # Public methods
 sub substitute_version {
    my ($self, $path, $from, $to) = @_;
@@ -19,13 +32,13 @@ sub substitute_version {
 }
 
 sub update_copyright_year : method {
-   my $self = shift; my ($from, $to) = $self->_get_update_args;
+   my $self = shift; my ($from, $to) = $self->$_get_update_args;
 
    my $prefix = $self->loc( 'Copyright (c)' );
 
-   $prefix or throw class => Unspecified, args => [ 'prefix' ];
-   $from   or throw class => Unspecified, args => [ 'from'   ];
-   $to     or throw class => Unspecified, args => [ 'to'     ];
+   $prefix or throw Unspecified, [ 'prefix' ];
+   $from   or throw Unspecified, [ 'from'   ];
+   $to     or throw Unspecified, [ 'to'     ];
 
    $self->output( 'Updating copyright year' );
 
@@ -37,9 +50,9 @@ sub update_copyright_year : method {
 }
 
 sub update_version : method {
-   my $self = shift; my ($from, $to) = $self->_get_update_args;
+   my $self = shift; my ($from, $to) = $self->$_get_update_args;
 
-   my $ignore = $self->_get_ignore_rev_regex;
+   my $ignore = $self->$_get_ignore_rev_regex;
 
    $self->output( 'Updating version numbers' );
 
@@ -65,19 +78,6 @@ sub update_version_pre_hook { # Can be modified by applied traits
    return @args;
 }
 
-# Private methods
-sub _get_ignore_rev_regex {
-   my $self = shift;
-
-   my $ignore_rev = $self->appldir->catfile( '.gitignore-rev' )->chomp;
-
-   return $ignore_rev->exists ? join '|', $ignore_rev->getlines : undef;
-}
-
-sub _get_update_args {
-   return ($_[ 0 ]->next_argv, $_[ 0 ]->next_argv);
-}
-
 1;
 
 __END__
@@ -178,7 +178,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
